@@ -2,7 +2,7 @@ package GD::SecurityImage::Styles;
 use strict;
 use vars qw[$VERSION];
 
-$VERSION = '1.20';
+$VERSION = '1.67';
 
 sub style_default {
    $_[0]->_drcommon(" \ lines will be drawn ");
@@ -62,6 +62,8 @@ sub style_ec {
       $self->style_circle(@_);
 }
 
+sub style_blank {}
+
 sub _drcommon {
    my $self  = shift;
    my $drawx = shift || 0;
@@ -101,6 +103,9 @@ See L<GD::SecurityImage>.
 
 =head1 DESCRIPTION
 
+This document describes version C<1.67> of C<GD::SecurityImage::Styles>
+released on C<18 April 2009>.
+
 This module contains the styles used in the security image.
 
 Used internally by L<GD::SecurityImage>. Nothing public here.
@@ -115,7 +120,7 @@ Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2004-2007 Burak GE<252>rsoy. All rights reserved.
+Copyright 2004-2008 Burak GE<252>rsoy. All rights reserved.
 
 =head1 LICENSE
 
